@@ -2,10 +2,10 @@
 # Globus::GRAM::JobManager
 #
 # CVS Information:
-#     $Source: /home/globdev/CVS/globus-packages/gram/jobmanager/scripts/JobManager.pm,v $
-#     $Date: 2013/09/06 19:58:46 $
-#     $Revision: 1.17.2.1 $
-#     $Author: bester $
+#     $Source$
+#     $Date$
+#     $Revision$
+#     $Author$
 #
 use Globus::GRAM::Error;
 use Globus::GRAM::JobState;
@@ -21,9 +21,11 @@ use strict;
 
 package Globus::GRAM::JobManager;
 
-my $cache_pgm = "$Globus::Core::Paths::bindir/globus-gass-cache-util";
-my $url_copy_pgm = "$Globus::Core::Paths::bindir/globus-url-copy";
-my $info_pgm = "$Globus::Core::Paths::bindir/grid-proxy-info";
+local %ENV;
+$ENV{PATH} = "$ENV{PATH}:${Globus::Core::Paths::bindir}";
+my $cache_pgm = "globus-gass-cache-util";
+my $url_copy_pgm = "globus-url-copy";
+my $info_pgm = "grid-proxy-info";
 
 =head1 NAME
 
